@@ -147,8 +147,7 @@ fn validate(name: &str, dep: &Dependency) -> Option<String> {
             Err(e) => {
                 return Some(format!(
                     "\"resolved\" is not a valid URL: \"{}\" ({})",
-                    resolved,
-                    e.to_string()
+                    resolved, e
                 ))
             }
         };
@@ -200,7 +199,7 @@ fn main() {
         let text = match fs::read_to_string(&path) {
             Ok(text) => text,
             Err(err) => {
-                println!("Error reading file: {}", err.to_string());
+                println!("Error reading file: {}", err);
                 found_errors = true;
                 continue;
             }
@@ -208,7 +207,7 @@ fn main() {
         let json: PackageLock = match serde_json::from_str(&text) {
             Ok(json) => json,
             Err(err) => {
-                println!("Error parsing JSON: {}", err.to_string());
+                println!("Error parsing JSON: {}", err);
                 found_errors = true;
                 continue;
             }
